#
# spec file for package mpiP
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor mpich%{nil}

%define pname mpiP

%if 0%{?sle_version:1} && 0%{?sle_version} < 150300
%define DisOMPI4 ExclusiveArch:  do_not_build
%endif
%if 0%{?sle_version:1} && 0%{?sle_version} < 160000
%define DisOMPI5 ExclusiveArch:  do_not_build
%endif

%if "%flavor" == ""
ExclusiveArch:  do_not_build
%define p_suffix %{nil}
%else
%define p_suffix -%{flavor}
%endif

%if "%{flavor}" == "openmpi4"
%{?DisOMPI4}
%endif

%if "%{flavor}" == "openmpi5"
ExcludeArch:    %{ix86} %{arm}
%{?DisOMPI5}
%endif

%define package_name %{pname}%{p_suffix}
%define p_prefix %{_libdir}/mpi/gcc/%{flavor}

%define p_bindir %{p_prefix}/bin
%define p_datadir %{p_prefix}/share
%define p_incdir %{p_prefix}/include/
%define p_libdir %{p_prefix}/%{_lib}/
%define p_libexecdir %{p_prefix}/%{_lib}
%define p_mandir %{p_prefix}/share/man

Name:           %{package_name}
Summary:        A profiling library for MPI applications
License:        BSD-3-Clause
Group:          Development/Tools/Debuggers
Version:        3.5
Release:        9.1
ExcludeArch:    i586 %arm s390
URL:            https://github.com/LLNL/mpiP
Source0:        https://github.com/LLNL/mpiP/releases/download/%{version}/mpip-%{version}.tgz#/%{pname}-%{version}.tgz
Patch1:         mpip.unwinder.patch
Patch2:         Add-return-value-to-non-void-function.patch
Patch3:         pc_lookup-replace-PTR-with-void.patch
Patch4:         configure-fix-compilation-error-for-GCC-14.patch
Patch5:         arch-add-generic-arch-using-GCC-builtins.patch
Patch6:         reproducible.patch

BuildRequires:  %{flavor}-devel
BuildRequires:  binutils-devel
BuildRequires:  dejagnu
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  libunwind-devel
BuildRequires:  python3
Requires:       %{flavor}

%description
mpiP is a profiling library for MPI applications.
It only collects statistical information about MPI functions, so mpiP
generates less overhead and much less data than tracing
tools. All the information captured by mpiP is task-local. It only
uses communication during report generation, typically at the end of
the experiment, to merge results from all of the tasks into one output
file.

%package devel
Summary:        Headers for profiling library for MPI applications
Group:          Development/Libraries/C and C++

%description devel
mpiP is a profiling library for MPI applications. This packages contains
the build headers.

%package devel-static
Summary:        Static version of profiling library for MPI applications
Group:          Development/Libraries/C and C++

%description devel-static
mpiP is a profiling library for MPI applications.

This package contains the static libraries.

%package doc
Summary:        Documentation for the mpiP profiling library
Group:          Documentation/Other

%description doc
mpiP is a profiling library for MPI applications.

This contains the documentation.

%prep
%setup -q -n %{pname}-%{version}
%autopatch -p0
sed -i -e "/-shared -o \$@/s#\(\${LDFLAGS}\)#\1 -Wl,-soname,\$@#" Makefile.in

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
export CC=gcc
source %{p_bindir}/mpivars.sh

export CC=mpicc
export CXX=mpicxx
export FC=mpifort
export F77=$FC
export CFLAGS="-D__DATE__=\\\"NODATE\\\" -D__TIME__=\\\"NOTIME\\\""
export FFLAGS="-std=legacy"
export HAVE_PYTHON="python3"
%configure \
  --prefix=%{p_prefix} \
  --exec-prefix=%{p_prefix} \
  --datadir=%{p_datadir} \
  --bindir=%{p_bindir} \
  --includedir=%{p_incdir} \
  --libdir=%{p_libdir} \
  --libexecdir=%{p_libexecdir} \
  --mandir=%{p_mandir} \
    --enable-demangling \
%ifarch aarch64
    --enable-setjmp \
%endif
    --docdir=%{_docdir}/%{name}

make %{?_smp_mflags} PYTHON="python3" shared

%install
source %{p_bindir}/mpivars.sh

make install-all DESTDIR=%{?buildroot}
find "%{buildroot}" -type f -name "*.a" -exec chmod a-x {} +
find "%{buildroot}/%{_docdir}" -type f -exec chmod a-x {} +
find "%{buildroot}/%{p_incdir}" -type f -exec chmod a-x {} +
for i in mpirun-mpip srun-mpip; do
    sed -i \
	-e "s@\(MPIP_DIR=\).*@\1%{?p_prefix}@" \
	-e "s@\(LD_PRELOAD=\).*:\(.*\)@\1\2@" \
	-e "s@\(ADDTL_RT_LIBS=.*\)@#\1@" \
	-e "s@/lib/libmpiP.so@/%{_lib}/libmpiP.so@" %{buildroot}%{p_bindir}/$i
done

%check
source %{p_bindir}/mpivars.sh
export CC=mpicc
export CXX=mpicxx
export FC=mpifort
export F77=$FC
export FFLAGS="-std=legacy"
LD_LIBRARY_PATH=$(pwd)${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
make FFLAGS+=${FFLAGS} check || exit 0

%files
%{p_libdir}/*so
%{p_bindir}

%files doc
%{_docdir}/%{name}/

%files devel
%{p_incdir}

%files devel-static
%{p_libdir}/*.a

%changelog
* Wed Apr 30 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to not add time and hostname of build (boo#1047218, boo#1084909)
* Mon Mar 24 2025 Nicolas Morey <nicolas.morey@suse.com>
- Disable and remove gnu-hpc build flavours (bsc#1239982)
- Enable non hpc flavours
* Thu Sep  5 2024 Nicolas Morey <nicolas.morey@suse.com>
- Refresh patched to git format
  - mpip.unwinder.patch
  - Add-return-value-to-non-void-function.patch
  - pc_lookup-replace-PTR-with-void.patch
- Add configure-fix-compilation-error-for-GCC-14.patch to
  fix compilation with GCC >= 14
- Add arch-add-generic-arch-using-GCC-builtins.patch to fix compilation
  on s390.
* Tue Jun 25 2024 Nicolas Morey <nicolas.morey@suse.com>
- Do not build on 32b platforms
* Fri Oct 20 2023 Nicolas Morey <nicolas.morey@suse.com>
- Drop support for openmpi[123] (jsc#PED-7111)
- Prepare support for openmpi5
* Tue Oct 10 2023 Nicolas Morey <nicolas.morey@suse.com>
- Drop %%vers macro so that the Version tag can be parsed more easily
* Mon Oct 24 2022 Steve Kowalik <steven.kowalik@suse.com>
- Use Python 3 instead of Python 2 to build.
* Mon Oct 17 2022 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Added pc_lookup-replace-PTR-with-void.patch to fix compilation
  on newer glibc.
* Sat Nov 28 2020 Egbert Eich <eich@suse.com>
- Update to mpiP version 3.5
  * Update deprecated functions.
  * Fix ARM typo and add LSE configure test.
  * Correct pt2pt histogram reporting check.
  * Address compiler warnings for some mt function return types.
  * Correct build behavior for testing multi-threaded support
    with Spectrum MPI.
  * Missing function argument entry.
  * Additional I/O routines
  * currBasetype fix
  * Update to test suite to include multi-threaded tests
  * Followup for renaming wrappers.c to mpiP-wrappers.c
  * Include mpiP in wrappers file name for call site reporting
  * Clarify stack tracing behavior
  * Correct autoheader error with HAVE_BFD_GET_SECTION_MACROS.
    Make define behavior consistent.
  * Convenience functionality to avoid SMPI libmpiP
  * Arch files corrections for gcc and opal code.
  * update to work with binutils-2.34
  * Fixed report header printing bug with large argument counts.
  * fix make-wrappers.py indentation and make python 2 and 3 compatible
  * Re-organized sizeof test to avoid CC defaulting to gcc.
    Re-organized default compilers.
  * Add Multi-Threading (MT) test suite
  * Fix FORTRAN Bindings: properly handle strings
  * Fix the code accounting the application time
  * Fix TLS cleanup code
  * Fix MT timings
  * Refine statistics reset procedure
  * Reduce the number of TLS accesses
  * First cut on multi-threading
  * Extract callsite code to a separate module
  * Move nested call check down the stack
  * Introduce additional statistics layer
  * First step towards MT support
  * Refactor global state: remove unneeded component
  * Preliminary step for adding multi-threaded support
  * Configury change: introduce mpiP-state.[c|h] files
  * Get rid of mpiPi.h.in file as unneeded
  * Adding autoconf PACKAGE defines to address current bfd.h
    requirement.
  * Fix mpi.h includes in some of the tests
  * Indentation fixes only. No actual changes.
  * Change default stack frame unwinding count.
  * Remove functions deprecated since MPI-2.0
  * Avoid LD_PRELOAD symbol conflict between srun and libiberty.
  * Create README.md
  * Corrected type issues resulting in compiler warnings in the
    test suite.
  * Make PC modification conditional. (Removed for now.)
  * Adding additional RMA functions to cover all MPI3.1 RMA
    functions. Expanded test coverage.
  * Added MPI3 One-sided operation support, from changes by Jeff Hammond.
  * Additional github migration.
  * Adding README.md
  * Added support for non-blocking collectives.
  * Provide non-NULL error argument for dwarf calls.
    Remove call to elf_end.  Ignore compile units with no
    function information, rather than abort.
  * Reduce unnecessary debugging output.
  * Add count column to top time section.
  * Adding fortran symbol failure output for debugging configure issues.
- Add build support for gcc10 to HPC build (bsc#1174439).
- Add openmpi4 flavors.
- Add: Add-return-value-to-non-void-function.patch
  Preliminary %%check stage. A number of checks fail currently.
  These need to be looked at.
* Wed May 13 2020 Egbert Eich <eich@suse.com>
- Enable openmpi3 build for all SLE versions.
* Fri Nov 29 2019 Egbert Eich <eich@suse.com>
- Add missing openmpi2 build for gcc7.
- Add support for gcc8 and gcc9 (jsc#SLE-7766 & jsc#SLE-8604).
- Include mpiP wrapper scripts for mpirun and Slurm srun.
- Package API.
* Thu Nov 28 2019 Egbert Eich <eich@suse.com>
- Disable openmpi1 builds for SLE/Leap > 15.1.
- Enable openmpi3 builds for Leap and SLE > 15.1 (jsc#SLE-7773).
* Thu Sep 26 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Fix LTO support in archive files
* Fri Mar  2 2018 cgoll@suse.com
- created version independent doc package
* Fri Feb  9 2018 eich@suse.com
- Add support for openmpi2 for HPC (FATE#325089).
* Fri Feb  9 2018 eich@suse.com
- Fix summary in module files (bnc#1080259).
* Fri Jan 12 2018 eich@suse.com
- Disable the openmpi3 flavor in some products.
* Fri Jan  5 2018 eich@suse.com
- Add gcc7 as additional compiler flavor for HPC on SLES.
- Add support for mpich and openmpi3 for HPC.
* Mon Nov 13 2017 eich@suse.com
- Require HPC devel packages.
* Sun Nov 12 2017 eich@suse.com
- Fix environment module file.
* Fri Oct 20 2017 eich@suse.com
- Enable the openmpi build since the HPC build for openmpi
  is now available in Factory.
* Fri Oct 13 2017 jengelh@inai.de
- Ensure neutrality of descriptions and trim subpackages.
* Fri Oct 13 2017 eich@suse.com
- Fix permissions in the doc and static package.
* Fri Sep  1 2017 eich@suse.com
- Initial package creation (FATE#321721).
- mpip.unwinder.patch:
  Fix AARCH64.
